======
mixsea
======


.. image:: https://img.shields.io/pypi/v/mixsea.svg
        :target: https://pypi.python.org/pypi/mixsea

.. image:: https://github.com/modscripps/mixsea/actions/workflows/mixsea-pytest.yml/badge.svg
        :target: https://github.com/modscripps/mixsea/actions/workflows/mixsea-pytest.yml

.. image:: https://readthedocs.org/projects/mixsea/badge/?version=stable
        :target: https://mixsea.readthedocs.io/en/latest/?badge=stable
        :alt: Documentation Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/psf/black


Ocean mixing parameterizations in python. 

* Free software: MIT license
* Documentation: https://mixsea.readthedocs.io.


Features
--------

* Thorpe scale based mixing estimates

* Shear/strain based mixing estimates

Credits
-------

For most parts based on theory and code previously developed in the
oceanographic community.
